"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const events_1 = __importDefault(require("events"));
class FileWatcher {
    constructor() {
        this.watchers = {};
        this.ee = new events_1.default();
        this.add = (file) => {
            const fileNames = typeof file === 'string' ? [file] : file;
            fileNames.forEach((fileName) => {
                this.watchers[fileName] = fs_1.default.watch(fileName, () => {
                    this.ee.emit('change', fileName);
                });
            });
            return this;
        };
        this.remove = (file) => {
            const fileNames = typeof file === 'string' ? [file] : file;
            fileNames.forEach((fileName) => {
                const watcher = this.watchers[fileName];
                if (watcher)
                    watcher.close();
                delete this.watchers[fileName];
            });
            return this;
        };
        this.clear = () => {
            const fileNames = Object.keys(this.watchers);
            this.remove(fileNames);
            return this;
        };
        this.on = (event, listener) => {
            this.ee.on(event, listener);
            return this;
        };
        this.off = (event, listener) => {
            this.ee.off(event, listener);
            return this;
        };
    }
}
exports.default = FileWatcher;
