"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const debug_1 = __importDefault(require("debug"));
const ora_1 = __importDefault(require("ora"));
const path_1 = __importDefault(require("path"));
const server_1 = require("../server");
const utils_1 = require("../utils");
const file_watcher_1 = __importDefault(require("./file-watcher"));
const isDev = process.env.NODE_ENV === 'development';
const debug = debug_1.default('mokia:cli');
const cwd = process.cwd();
const spinner = ora_1.default();
const noop = () => {
    /* */
};
const tsOptions = {
    compilerOptions: {
        target: 'es6',
        module: 'commonjs',
        lib: ['dom', 'es2016', 'es2017'],
        strictPropertyInitialization: false,
        noUnusedLocals: false,
        moduleResolution: 'node',
        allowSyntheticDefaultImports: true,
        esModuleInterop: true,
        experimentalDecorators: true,
        emitDecoratorMetadata: true
    }
};
function run(cli) {
    return __awaiter(this, void 0, void 0, function* () {
        const { input, flags } = cli;
        const configPath = path_1.default.join(cwd, input[0] || 'index.ts');
        if (flags.debug) {
            debug_1.default.enable('mokia:*');
        }
        debug('isDev', isDev);
        debug('configPath', configPath);
        debug('flag ', flags);
        if (/\.ts$/.test(configPath)) {
            debug('enable TypeScript...');
            require('ts-node').register(tsOptions);
        }
        const ignoreRegExp = isDev ? /node_modules|mokia/ : /node_modules/;
        try {
            let destroy = yield start(configPath, flags);
            let dependencies = utils_1.getDependencies(configPath, ignoreRegExp);
            debug('dependencies', dependencies);
            if (flags.watch) {
                const watcher = new file_watcher_1.default();
                watcher.add(dependencies);
                watcher.on('change', utils_1.debounce((file) => __awaiter(this, void 0, void 0, function* () {
                    debug('file change', file);
                    utils_1.log(chalk_1.default.yellow('*'), `Server is restarting...`);
                    spinner.start('Loading...\n');
                    yield destroy();
                    debug('destroyed');
                    dependencies.forEach((dep) => cleanCache(dep));
                    watcher.clear();
                    destroy = yield start(configPath, flags);
                    dependencies = utils_1.getDependencies(configPath, ignoreRegExp);
                    watcher.add(dependencies);
                    debug('dependencies', dependencies);
                }), 500));
            }
        }
        catch (error) {
            spinner.fail(error.message);
            process.exit(1);
        }
        if (flags.version)
            cli.showVersion();
        if (flags.help)
            cli.showHelp();
    });
}
exports.default = run;
function start(configPath, options) {
    return __awaiter(this, void 0, void 0, function* () {
        spinner.start('Loading...');
        let config;
        try {
            config = yield Promise.resolve().then(() => __importStar(require(configPath)));
            if (config && config.default)
                config = config.default;
        }
        catch (error) {
            debug('error', error);
            spinner.fail(`Could not load: ${configPath}, waiting for change...`);
            return noop;
        }
        if (options.host)
            config[server_1.HOST] = options.host;
        if (options.port)
            config[server_1.PORT] = options.port;
        if (options.prefix)
            config[server_1.PREFIX] = options.prefix;
        if (options.silent)
            config[server_1.SILENT] = options.silent;
        if (options.priority)
            config[server_1.PRIORITY] = options.priority;
        const [port, destroy] = yield server_1.create(config);
        spinner.succeed(`Server is listening on port ${chalk_1.default.green(port.toString())}.`);
        return destroy;
    });
}
function cleanCache(configPath) {
    const module = require.cache[configPath];
    const siblings = module && module.parent && module.parent.children;
    if (siblings) {
        const index = siblings.indexOf(module);
        siblings.splice(index, 1);
    }
    require.cache[configPath] = null;
}
process.on('unhandledRejection', (err) => {
    debug('unhandled rejection', err);
});
