"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("../constants");
const utils_1 = require("../utils");
/**
 * Returns boolean value
 *
 * @example
 *
 * boolean()
 * // => true / false
 *
 * boolean(1)
 * // => true
 *
 * boolean(1, false)
 * // => false
 */
function boolean(chance = 0.5, value = true) {
    chance = Math.min(Math.max(chance, 0), 1);
    return Math.random() < chance ? Boolean(value) : !value;
}
exports.boolean = boolean;
function integer(n1, n2) {
    if (n2 === undefined) {
        n2 = utils_1.ensureInteger(n1, constants_1.MAX_INTEGER);
        n1 = n1 === undefined ? -constants_1.MAX_INTEGER : 0;
    }
    else {
        n1 = parseInt(n1, 10);
        n2 = parseInt(n2, 10);
    }
    const min = Math.min(n1, n2);
    const max = Math.max(n1, n2);
    return Math.round(Math.random() * (max - min)) + min;
}
exports.integer = integer;
function natural(n1, n2) {
    if (n2 === undefined) {
        n2 = utils_1.ensureNatural(n1, constants_1.MAX_INTEGER);
        n1 = 0;
    }
    else {
        n1 = utils_1.ensureNatural(n1);
        n2 = utils_1.ensureNatural(n2);
    }
    const min = Math.min(n1, n2);
    const max = Math.max(n1, n2);
    return Math.round(Math.random() * (max - min)) + min;
}
exports.natural = natural;
function float(n1, n2, n3, n4) {
    const min = utils_1.defaultBy(n2, utils_1.defaultTo(n1, 0), 0);
    const max = utils_1.defaultTo(n2, utils_1.defaultTo(n1, 100));
    const dmin = utils_1.defaultTo(n3, 1);
    const dmax = utils_1.defaultTo(n4, utils_1.defaultTo(n3, 3));
    const decLen = integer(dmin, dmax);
    const int = integer(min, max);
    const dec = decLen > 0 ? string(constants_1.pools.number, decLen - 1) + char(constants_1.pools.positive) : '';
    return parseFloat(`${int}.${dec}`);
}
exports.float = float;
/**
 * Returns a char
 *
 * @example
 *
 * char()
 * // => 'v'
 *
 * char('0123456789')
 * // => '6'
 */
function char(pool) {
    return pool.charAt(natural(pool.length - 1));
}
exports.char = char;
function string(pool, n1, n2) {
    const max = utils_1.defaultTo(n2, utils_1.defaultTo(n1, 10));
    const min = utils_1.defaultTo(n1, 0);
    const len = natural(min, max);
    let text = '';
    for (let i = 0; i < len; i++) {
        text += char(pool);
    }
    return text;
}
exports.string = string;
