"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../utils");
const constants_1 = require("../constants");
let hue = Math.random();
function randomHue() {
    return hue = (hue + constants_1.GOLDEN_RATIO_CONJUGATE) % 1;
}
/**
 * Returns a hex color string
 *
 * @example
 *
 * hex()
 * // => '#79f2e1'
 */
function hex() {
    const values = utils_1.hslToRgb(randomHue(), 0.5, 0.6)
        .map((v) => Math.round(v * 255).toString(16).padStart(2, '0'))
        .join('');
    return '#' + values;
}
exports.hex = hex;
/**
 * Returns a rgb color string
 *
 * @example
 *
 * rgb()
 * // => 'rgb(228, 242, 124)'
 */
function rgb() {
    const values = utils_1.hslToRgb(randomHue(), 0.5, 0.6)
        .map((v) => Math.round(v * 255))
        .join(', ');
    return 'rgb(' + values + ')';
}
exports.rgb = rgb;
/**
 * Returns a rgba color string
 *
 * @example
 *
 * rgba()
 * // => 'rgba(242, 149, 121, 0.51)'
 */
function rgba() {
    const values = utils_1.hslToRgb(randomHue(), 0.5, 0.6)
        .map((v) => Math.round(v * 255))
        .join(', ');
    return 'rgba(' + values + ', ' + Math.random().toFixed(2) + ')';
}
exports.rgba = rgba;
/**
 * Returns a hsl color string
 *
 * @example
 *
 * hsl()
 * // => 'hsl(58, 50%, 60%)'
 */
function hsl() {
    const h = Math.round(randomHue() * 360);
    return 'hsl(' + h + ', 50%, 60%)';
}
exports.hsl = hsl;
/**
 * Returns a hex color string
 *
 * @example
 *
 * color()
 * // => '#79f2e1'
 */
function color() {
    return hex();
}
exports.color = color;
