"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const basic_1 = require("./basic");
const mockable_1 = require("../mockable");
const utils_1 = require("../utils");
/**
 * Returns object generated by specified schema
 *
 * @example
 *
 * generate({ name: 'Harrie' })
 * // => { name: 'Harrie' }
 *
 * generate({ name: fullName() })
 * // => { name: '张三' }
 *
 * generate(() => 'Harrie')
 * // => 'Harrie'
 *
 * generate(null)
 * // => null
 */
function generate(mockable) {
    if (typeof mockable === 'function')
        return mockable();
    if (!utils_1.isTrueObject(mockable))
        return mockable;
    const result = {};
    for (const key in mockable) {
        if (mockable.hasOwnProperty(key)) {
            const invoker = mockable[key];
            result[key] = typeof invoker === 'function'
                ? invoker.call(result)
                : invoker;
        }
    }
    return result;
}
exports.generate = generate;
function array(proto, n1, n2) {
    const max = utils_1.defaultTo(n2, utils_1.defaultTo(n1, 5));
    const min = utils_1.defaultTo(n1, 2);
    const count = basic_1.integer(min, max);
    const mockable = utils_1.isFunction(proto) ? proto : mockable_1.getMockable(proto);
    const results = [];
    for (let i = 0; i < count; i++) {
        results.push(generate(mockable));
    }
    return results;
}
exports.array = array;
/**
 * Returns an item of list
 *
 * @example
 *
 * oneOf(['a', 'b'. 'c'])
 * // => 'b'
 */
function oneOf(list) {
    const index = basic_1.integer(0, list.length - 1);
    return list[index];
}
exports.oneOf = oneOf;
function manyOf(list, n1, n2) {
    const max = utils_1.defaultTo(n2, utils_1.defaultTo(n1, list.length));
    const min = utils_1.defaultTo(n1, 0);
    const count = basic_1.integer(min, max);
    return utils_1.pickItems(list, count);
}
exports.manyOf = manyOf;
function pick(proto, n1, n2) {
    if (!utils_1.isTrueObject(proto))
        return null;
    const mockable = mockable_1.getMockable(proto);
    const result = generate(mockable);
    const keys = n1 === undefined || typeof n1 === 'number'
        ? manyOf(Object.keys(result), n1, n2)
        : n1;
    return utils_1.pickProps(result, keys);
}
exports.pick = pick;
