"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("./constants");
const basic_1 = require("../../basic");
const constants_2 = require("../../../constants");
const person_1 = require("../../person");
const complex_1 = require("../../complex");
/**
 * Returns a full name
 *
 * @example
 * fullName()
 * // => '陶楷呈'
 */
function fullName() {
    return firstName() + lastName();
}
exports.fullName = fullName;
/**
 * Returns a first name
 *
 * @example
 * firstName()
 * // => '于'
 */
function firstName() {
    return complex_1.oneOf(constants_1.FIRST_NAMES.split(' '));
}
exports.firstName = firstName;
/**
 * Returns a last name
 *
 * @example
 * lastName()
 * // => '文函'
 */
function lastName() {
    return complex_1.oneOf(constants_1.LAST_NAMES.split(' '));
}
exports.lastName = lastName;
/**
 * Returns a phone number
 *
 * @example
 * phone()
 * // => '13897496187'
 */
function phone() {
    return complex_1.oneOf(constants_1.PHONE_PREFIX.split(' ')) + basic_1.string(constants_2.NUMBERS, 8);
}
exports.phone = phone;
/**
 * Returns an id number
 *
 * @example
 * // => '44156197601061635'
 */
function idNumber() {
    const prefix = basic_1.char(constants_2.pools.positive) + basic_1.string(constants_2.pools.number, 5);
    const suffix = basic_1.string(constants_2.pools.number, 3) + basic_1.char('0123456789x');
    return prefix + person_1.birthday('YYYYMMDD') + suffix;
}
exports.idNumber = idNumber;
