"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const constant_regions_1 = __importDefault(require("./constant-regions"));
const complex_1 = require("../../complex");
const basic_1 = require("../../basic");
/**
 * Returns a province
 *
 * @example
 * province()
 * // => { code: '440000', name: '广东省' }
 */
function province() {
    const { code, name } = complex_1.oneOf(constant_regions_1.default);
    return { code, name };
}
exports.province = province;
/**
 * Returns a province name
 *
 * @example
 * provinceName()
 * // => '广东省'
 */
function provinceName() {
    return province().name;
}
exports.provinceName = provinceName;
/**
 * Returns a city
 *
 * @example
 * city()
 * // => { code: '440100', name: '广州市' }
 */
function city() {
    let p = complex_1.oneOf(constant_regions_1.default);
    while (!p.children) {
        p = complex_1.oneOf(constant_regions_1.default);
    }
    const { code, name } = complex_1.oneOf(p.children);
    return { code, name };
}
exports.city = city;
/**
 * Returns a city name
 *
 * @example
 * cityName()
 * // => '广州市'
 */
function cityName() {
    return city().name;
}
exports.cityName = cityName;
/**
 * Returns a county
 *
 * @example
 * county()
 * // => { code: '440105', name: '海珠区' }
 */
function county() {
    let p = complex_1.oneOf(constant_regions_1.default);
    while (!p.children) {
        p = complex_1.oneOf(constant_regions_1.default);
    }
    const { code, name } = complex_1.oneOf(complex_1.oneOf(p.children).children);
    return { code, name };
}
exports.county = county;
/**
 * Returns a county name
 *
 * @example
 * countyName()
 * // => '海珠区'
 */
function countyName() {
    return county().name;
}
exports.countyName = countyName;
/**
 * Returns a region
 *
 * @example
 * region()
 * // => [
 *         { code: '440000', name: '广东省' },
 *         { code: '440100', name: '广州市' },
 *         { code: '440105', name: '海珠区' }
 *       ]
 */
function region() {
    const regionList = [];
    const _a = complex_1.oneOf(constant_regions_1.default), { children: children1 } = _a, region1 = __rest(_a, ["children"]);
    regionList.push(region1);
    if (!children1)
        return regionList;
    const _b = complex_1.oneOf(children1), { children: children2 } = _b, region2 = __rest(_b, ["children"]);
    regionList.push(region2);
    if (!children2)
        return regionList;
    const region3 = complex_1.oneOf(children2);
    regionList.push(region3);
    return regionList;
}
exports.region = region;
/**
 * Returns a region name
 *
 * @example
 * regionName()
 * // => '广东省 广州市 海珠区'
 */
function regionName() {
    return region().map((r) => r.name).join(' ');
}
exports.regionName = regionName;
/**
 * Returns a zip code
 *
 * @example
 * zip()
 * // => '159041'
 */
function zipCode() {
    return Array.from({ length: 6 }).map(() => basic_1.integer(0, 9)).join('');
}
exports.zipCode = zipCode;
