"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../utils");
const basic_1 = require("./basic");
const complex_1 = require("./complex");
const constants_1 = require("../constants");
const date_1 = require("./date");
/**
 * Returns an age
 *
 * @example
 * age()
 * // => 58
 */
function age(min, max) {
    min = utils_1.clamp(utils_1.defaultTo(min, 1), 1, 100);
    max = utils_1.clamp(utils_1.defaultTo(max, 100), 1, 100);
    return basic_1.integer(min, max);
}
exports.age = age;
/**
 * Returns a birthday
 *
 * @example
 * birthday()
 * // => '1975-05-08'
 */
function birthday(format) {
    return date_1.date(format || constants_1.DATE_FORMAT, '1900-01-01', Date.now());
}
exports.birthday = birthday;
/**
 * Returns a full name
 *
 * @example
 * fullName()
 * // => 'Ronnie Howard'
 */
function fullName() {
    return firstName() + ' ' + lastName();
}
exports.fullName = fullName;
/**
 * Returns a first name
 *
 * @example
 * firstName()
 * // => 'Evie'
 */
function firstName() {
    return complex_1.oneOf(constants_1.FIRST_NAMES);
}
exports.firstName = firstName;
/**
 * Returns a last name
 *
 * @example
 * lastName()
 * // => 'Parker'
 */
function lastName() {
    return complex_1.oneOf(constants_1.LAST_NAMES);
}
exports.lastName = lastName;
