"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const express_1 = __importDefault(require("express"));
const utils_1 = require("../utils");
function createRouter(routes, payloadKey, silent) {
    const router = express_1.default.Router();
    if (!silent) {
        router.use(logHandler);
    }
    for (const key in routes) {
        if (routes.hasOwnProperty(key)) {
            const [method, url] = parseRoute(key);
            const route = ensureRoute(routes[key]);
            const handler = createRequestHandler(route, payloadKey);
            if (isValidMethod(method) && url) {
                router[method](url, handler);
            }
        }
    }
    return router;
}
exports.createRouter = createRouter;
const methods = ['get', 'post', 'put', 'patch', 'delete', 'options'];
function parseRoute(key) {
    const [method, url] = key.split(' ');
    return [method.toLowerCase(), url];
}
function ensureRoute(route) {
    return typeof route === 'object' ? () => route : route;
}
function isValidMethod(method) {
    return methods.includes(method);
}
function createRequestHandler(route, payloadKey) {
    return (request, response, next) => {
        const data = route(request, response);
        if (data)
            response.locals[payloadKey] = data;
        next();
    };
}
function logHandler(req, res, next) {
    const method = req.method;
    const url = req.url;
    utils_1.log('- ', utils_1.colors[method](method), url);
    next();
}
