"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const body_parser_1 = __importDefault(require("body-parser"));
const cors_1 = __importDefault(require("cors"));
const debug_1 = __importDefault(require("debug"));
const express_1 = __importDefault(require("express"));
const route_1 = require("./route");
const middlewares_1 = require("./middlewares");
const debug = debug_1.default('mokia:server');
exports.HOST = Symbol('HOST');
exports.PORT = Symbol('PORT');
exports.PREFIX = Symbol('PREFIX');
exports.SILENT = Symbol('SILENT');
exports.PRIORITY = Symbol('PRIORITY');
exports.INTERCEPTORS = Symbol('INTERCEPTORS');
// Why not Symbol: https://github.com/microsoft/TypeScript/issues/1863
exports.PAYLOAD_KEY = 'PAYLOAD_KEY';
function create(config) {
    return new Promise((resolve, reject) => {
        const _a = exports.HOST, _b = config[_a], host = _b === void 0 ? 'localhost' : _b, _c = exports.PORT, _d = config[_c], port = _d === void 0 ? 8080 : _d, _e = exports.PREFIX, _f = config[_e], prefix = _f === void 0 ? '' : _f, _g = exports.SILENT, _h = config[_g], silent = _h === void 0 ? false : _h, _j = exports.PRIORITY, _k = config[_j], priority = _k === void 0 ? '' : _k, _l = exports.INTERCEPTORS, _m = config[_l], interceptors = _m === void 0 ? {} : _m, routes = __rest(config, [typeof _a === "symbol" ? _a : _a + "", typeof _c === "symbol" ? _c : _c + "", typeof _e === "symbol" ? _e : _e + "", typeof _g === "symbol" ? _g : _g + "", typeof _j === "symbol" ? _j : _j + "", typeof _l === "symbol" ? _l : _l + ""]);
        debug('host', host);
        debug('port', port);
        debug('prefix', prefix);
        debug('silent', silent);
        debug('routes', routes);
        debug('interceptors', interceptors);
        const app = express_1.default()
            .use(cors_1.default())
            .use(body_parser_1.default.json())
            .use(body_parser_1.default.urlencoded({ extended: false }));
        if (interceptors.request)
            app.use(middlewares_1.interceptor(interceptors.request, exports.PAYLOAD_KEY));
        if (priority)
            app.use(middlewares_1.priorityHandler(priority));
        app.use(prefix, route_1.createRouter(routes, exports.PAYLOAD_KEY, silent));
        if (interceptors.response)
            app.use(middlewares_1.interceptor(interceptors.response, exports.PAYLOAD_KEY));
        app.use((req, res) => res.json(res.locals[exports.PAYLOAD_KEY]));
        app.on('error', reject);
        const intPort = typeof port === 'string' ? parseInt(port, 10) : port;
        const server = app.listen(intPort, host, () => resolve([intPort, destroy]));
        const connections = new Set();
        server.on('connection', (conn) => {
            connections.add(conn);
            conn.on('close', () => connections.delete(conn));
        });
        function destroy() {
            return new Promise((res, rej) => {
                if (!server)
                    return res();
                connections.forEach((conn) => conn.destroy());
                server.close(() => res());
            });
        }
    });
}
exports.create = create;
