"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const path_1 = __importDefault(require("path"));
exports.log = console.log;
exports.colors = {
    GET: chalk_1.default.green,
    POST: chalk_1.default.blue,
    PUT: chalk_1.default.yellow,
    PATCH: chalk_1.default.magenta,
    DELETE: chalk_1.default.red,
    OPTIONS: chalk_1.default.gray
};
/**
 * Returns a debounced function
 *
 * @example
 *
 * debounce(function () { }, 200)
 */
function debounce(fn, delay) {
    let timer;
    return function (...args) {
        clearTimeout(timer);
        timer = setTimeout(() => {
            fn.apply(this, args);
        }, delay);
    };
}
exports.debounce = debounce;
/**
 * Concat urls
 *
 * @example
 *
 * concatUrls('/aaa', 'bbb', 'ccc', '/ddd')
 * // => '/aaa/bbb/ccc/ddd'
 */
function concatUrls(...urls) {
    return urls.map((u, i) => (i > 0 && u[0] !== '/' ? '/' + u : u)).join('');
}
exports.concatUrls = concatUrls;
/**
 * Get all dependencies.
 *
 * @example
 *
 * getDependencies('./index.js')
 * // => []
 */
function getDependencies(rootPath, ignore) {
    const module = require.cache[path_1.default.resolve(rootPath)];
    const modules = new Set();
    const loopModule = (m) => {
        if ((ignore && ignore.test(m.filename)) || modules.has(m.filename))
            return;
        modules.add(m.filename);
        m.children.forEach(loopModule);
    };
    loopModule(module);
    return [...modules];
}
exports.getDependencies = getDependencies;
