/**
 * Returns object generated by specified schema
 *
 * @example
 *
 * generate({ name: 'Harrie' })
 * // => { name: 'Harrie' }
 *
 * generate({ name: fullName() })
 * // => { name: '张三' }
 *
 * generate(() => 'Harrie')
 * // => 'Harrie'
 *
 * generate(null)
 * // => null
 */
export declare function generate(mockable: any): any;
/**
 * Returns an array with random length
 *
 * @example
 *
 * array('a')
 * // => ['a']
 *
 * array('a', 3)
 * // => ['a', 'a', 'a']
 *
 * array('a', 3, 5)
 * // => ['a', 'a', 'a', 'a']
 *
 * array({ name: fullName() }, 2)
 * // => [{ name: '张三' }, { name: '李四' }]
 */
export declare function array<T>(proto: T, length?: number): T extends (...args: any[]) => infer R ? R[] : T[];
export declare function array<T>(proto: T, min: number, max: number): T extends (...args: any[]) => infer R ? R[] : T[];
/**
 * Returns an item of list
 *
 * @example
 *
 * oneOf(['a', 'b'. 'c'])
 * // => 'b'
 */
export declare function oneOf<T>(list: T[]): T;
/**
 * Returns new list pick from another list
 *
 * @example
 *
 * manyOf(['a', 'b', 'c'])
 * // => ['b', 'c']
 *
 * manyOf(['a', 'b', 'c', 'd', 'e'], 2)
 * // => ['e', 'b']
 *
 * manyOf(['a', 'b', 'c', 'd', 'e'], 2, 5)
 * // => ['c', 'e', 'a']
 */
export declare function manyOf<T>(list: T[], length?: number): T[];
export declare function manyOf<T>(list: T[], min: number, max: number): T[];
/**
 * Returns an object with properties picked from another object
 *
 * @example
 *
 * pick({ name: 'Harrie', age: 18, gender: 'male' }, 'name age')
 * // => ({ name: 'Harrie', age: 18 }
 *
 * pick({ name: 'Harrie', age: 18, gender: 'male' }, ['name', 'age'])
 * // => ({ name: 'Harrie', age: 18 }
 *
 * pick({ name: 'Harrie', age: 18, gender: 'male' }, 2)
 * // => ({ age: 18 }
 *
 * pick({ name: 'Harrie', age: 18, gender: 'male' }, 1, 2)
 * // => ({ age: 18, gender: 'male' }
 */
export declare function pick<T>(proto: T, length?: number): T extends Object ? Partial<T> : null;
export declare function pick<T>(proto: T, props: string | string[]): T extends Object ? Partial<T> : null;
export declare function pick<T>(proto: T, min: number, max: number): T extends Object ? Partial<T> : null;
