/**
 * Returns a protocol
 *
 * @example
 *
 * protocol()
 * // => 'http'
 */
export declare function protocol(): string;
/**
 * Returns a tld
 *
 * @example
 *
 * tld()
 * // => 'hk'
 */
export declare function tld(): string;
/**
 * Returns an ip address
 *
 * @example
 *
 * ip()
 * // => '233.173.228.16
 */
export declare function ip(): string;
/**
 * Returns an ipv6 address
 *
 * @example
 *
 * ipv6()
 * // => 'b35c:9ff1:66d4:607e:4e7e:b3e7:36d:f7f3
 */
export declare function ipv6(): string;
/**
 * Returns a port number
 *
 * @example
 *
 * port()
 * // => 5286
 */
export declare function port(min?: number, max?: number): number;
/**
 * Returns a domain
 *
 * @example
 *
 * domain()
 * // => 'xfoekq.cn'
 *
 * domain('hk')
 * // => 'voewpzn.hk'
 */
export declare function domain(_tld?: string): string;
/**
 * Returns a pathname
 *
 * @example
 * pathname()
 * // => '/o8qpgvk/ask2ih/cey'
 *
 * pathname(2)
 * // => '/qutmva/flq2'
 */
export declare function pathname(length?: number): string;
/**
 * Returns an url
 *
 * @example
 *
 * url()
 * // => 'mailto://wobiq.com/jqpvk/qogx'
 *
 * url('https')
 * // => 'https://ieyqjo.org/cktoqm/zlire/aw/gaoq'
 *
 * url('https', 'github.com')
 * // => 'https://github.com/owiytj/akwpt/bns'
 *
 * url('https', 'github.com', 'varHarrie')
 * // => 'https://github.com/varHarrie/nchgyuel/aj/qigpjvr'
 */
export declare function url(_protocol?: string, host?: string, prefix?: string): string;
/**
 * Return a email address
 *
 * @example
 *
 * email()
 * // => 'rih.zqgll@owk.cn'
 *
 * email('gmail.com')
 * // => 'bqignwo.qzu@gmail.com'
 */
export declare function email(_domain?: string): string;
